@@ -2,8 +2,8 @@
    Cascade Menu Ver 2.0
    Copyright(c) 1996 Go Watanabe     go@cclub.tutcc.tut.ac.jp
 */
-#ifndef CascadeMenuP_h
-#define CascadeMenuP_h
+#ifndef __CascadeMenuP_h
+#define __CascadeMenuP_h
 
 #ifndef XAW3D
 #include <X11/Xaw/SimpleMenP.h>
