@@ -15,6 +15,11 @@
 #include "SmeCascade.h"
 
 /* class */
+
+typedef struct{
+	Pixmap default_right_bitmap;
+} SmeCascadeClassPart;
+
 typedef struct _SmeCascadeClassRec {
     RectObjClassPart	rect_class;
     SmeClassPart		sme_class;
@@ -22,6 +27,7 @@ typedef struct _SmeCascadeClassRec {
     SmeThreeDClassPart  sme_threeD_class;
 #endif
     SmeBSBClassPart		sme_bsb_class;
+	SmeCascadeClassPart	sme_cas_class;
 } SmeCascadeClassRec;
 
 extern SmeCascadeClassRec smeCascadeClassRec;
